@@ -1,7 +1,9 @@
 package Log::ger::Manual;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-18'; # DATE
-our $VERSION = '0.028.008'; # VERSION
+our $DIST = 'Log-ger-Manual'; # DIST
+our $VERSION = '0.029.000'; # VERSION
 
 1;
 # ABSTRACT: Manual for Log::ger
@@ -18,7 +20,7 @@ Log::ger::Manual - Manual for Log::ger
 
 =head1 VERSION
 
-version 0.028.008
+version 0.029.000
 
 =head1 DESCRIPTION
 
